@@ -299,3 +299,27 @@ class FlaviusHeaderSetTaxReduceWithDid(FlaviusBase):
             create_url='',
             update_url=conf.FLAVIUS_API_HEADER_SET_TAX_REDUCE_WITH_DID,
             delete_url='')
+
+
+class FlaviusHeaderSetTaxReduce(FlaviusBase):
+    """
+    軽減税率適用API
+    """
+    def __init__(self):
+        super(FlaviusHeaderSetTaxReduce, self).__init__(
+            search_url='',
+            create_url='',
+            update_url=conf.FLAVIUS_API_HEADER_SET_TAX_REDUCE,
+            delete_url='')
+
+
+class FlaviusItemSearchTaxReduce(FlaviusBase):
+    """
+    軽減税率適用API
+    """
+    def __init__(self):
+        super(FlaviusItemSearchTaxReduce, self).__init__(
+            search_url=conf.FLAVIUS_API_ITEM_SEARCH_TAX_REDUCE,
+            create_url='',
+            update_url='',
+            delete_url='')
